#<profile4xi profile = "02" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "eventproxy4xi.py">
#<abstract4xi abstract = "provides class EventProxy4Xi"/>
#<refer4xi reference = "managers.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------
#

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'EventProxy4Xi' ]
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:
    import _winapi
except:
    pass

                
try:                 # most-common ones
    import weakref
    import array
    import queue
    from traceback import format_exc         
except:
    pass
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
try:                             # Binary ones 
    import _multiprocessing
except:
    pass
try:                             # Python ones
    from multiprocessing.managers import EventProxy
except:
    print("eventproxy4xi.py *** failed in from multiprocessing.managers import EventProxy4Xi ***")
#"
#/>

# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from baseproxy4xi import BaseProxy4Xi

from constant_managers4xi import get_clear_manager4xi
from constant_managers4xi import get_is_set_manager4xi
from constant_managers4xi import get_set_manager4xi
from constant_managers4xi import get_wait_manager4xi

from reason_object4xi import reason_object4xi

from sense_object4xi import sense_object4xi
from timeout4xi import omega2timeout4xi
from print4xi import print4xi
from time4xi import time4xi    
#"
#/>


# =================================================================================================
#<class4xi class = "EventProxy4Xi" base = "BaseProxy4Xi" child = "None" synopsis = "given as a parameter to SyncManager4Xi" usage = "
#     managers.py
#         SyncManager.register('Event', threading.Event, EventProxy) <--- in this module 
#    syncmanager4xi.py:
#         SyncManager4Xi.register('Event4Xi', threading.Event, EventProxy4Xi)"
#>
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# =================================================================================================
#
class EventProxy4Xi(BaseProxy4Xi):
    '''
    EventProxy4Xi class: given as a parameter to SyncManager4Xi
    '''
 
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi exposure = "
    _exposed_ = ('is_set', 'set', 'clear', 'wait', 'sense', 'reason', 'ace')
    #"
    #/>
                                     
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "is-set-of-EventProxy4Xi" usage = "returns with (self)">                          
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def is_set(self):
        '''
        EventProxy4Xi method is_set: returns with (self)     
        '''
        class2print = "EventProxy4Xi"
        method2print = "is_set"
        
        message2print = "{started" + "; is-set-of-EventProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                        
        is2xi = get_is_set_manager4xi() #IS_SET_MANAGER4XI
                          
        message2print = "{passing" + "; is2xi-passing-to-callmethod-of-eventproxy2xi-by-is-set-of-EventProxy4Xi: " + str(is2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                                
        message2print = "{returning" + "; callmethod-of-eventproxy2xi-returning-by-is-set-of-EventProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                       
        return self._callmethod(is2xi) 
    #</methodize4xi>
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-of-EventProxy4Xi" usage = "returns with (self) ">                         
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def set(self):
        '''
        EventProxy4Xi method set: returns with (self)     
        '''
        class2print = "EventProxy4Xi"
        method2print = "set"
        
        message2print = "{started" + "; set-of-EventProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   

        set2xi = get_set_manager4xi() #SET_MANAGER4XI
                          
        message2print = "{passing" + "; set2xi-passing-to-callmethod-of-eventproxy2xi-by-set-of-EventProxy4Xi: " + str(set2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
                                
        message2print = "{returning" + "; callmethod-of-eventproxy2xi-returning-by-set-of-EventProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                            
        
        return self._callmethod(set2xi) 
    #</methodize4xi>
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "clear-of-EventProxy4Xi" usage = "returns with (self)">                            
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def clear(self):
        '''
        EventProxy4Xi method clear: returns with (self)     
        '''
        class2print = "EventProxy4Xi"
        method2print = "clear"
        
        message2print = "{started" + "; clear-of-EventProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        clear2xi = get_clear_manager4xi() #CLEAR_MANAGER4XI     

                          
        message2print = "{passing" + "; clear2xi-passing-to-callmethod-of-eventproxy2xi-by-clear-of-EventProxy4Xi: " + str(clear2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
             
                                
        message2print = "{returning" + "; callmethod-of-eventproxy2xi-returning-by-clear-of-EventProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
            
        return self._callmethod(clear2xi) 
    #</methodize4xi>
            
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "wait-of-EventProxy4Xi" usage = "returns with (self,timeout)">                       
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def wait(self, timeout=None):
        '''
        EventProxy4Xi method wait:  returns with (self,timeout)    
        '''
        class2print = "EventProxy4Xi"
        method2print = "wait"
        
        message2print = "{started" + "; wait-of-EventProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        timeout = omega2timeout4xi(class2print, method2print) 

        message2print = "{set" + "; timeout-set-by-wait-of-EventProxy4Xi to: " + str(timeout)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        
        wait2xi = get_wait_manager4xi() #WAIT_MANAGER4XI
                          
        message2print = "{passing" + "; wait2xi-passing-to-callmethod-of-eventproxy2xi-by-wait-of-EventProxy4Xi: " + str(wait2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                          
        message2print = "{passing" + "; timeout-passing-to-callmethod-of-eventproxy2xi-by-wait-of-EventProxy4Xi: " + str(timeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                                
        message2print = "{returning" + "; callmethod-of-eventproxy2xi-returning-by-wait-of-EventProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                  
        return self._callmethod(wait2xi, timeout) 
    #</methodize4xi>
            
                                       
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-EventProxy4Xi" usage = "senses EventProxy4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        method sense: senses EventProxy4Xi class objects
        '''
          
        
        class2print = 'EventProxy4Xi'
        method2print = 'sense'
        
        message2print = "{started" + "; sense-of-EventProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; EventProxy4Xi-sensing-by-sense-of-EventProxy4Xi: " + str(EventProxy4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                     

                        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-EventProxy4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                

                        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['inheritance-of-eventproxy2xi'] = BaseProxy4Xi
        except:
            message2print = "{yielded" + "; kb2xi-yielded-by-sense-of-EventProxy4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 

        
        
      
        message2print = "{sensed" + "; EventProxy4Xi-sensed-by-sense-of-EventProxy4Xi: " + str(EventProxy4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)      
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-EventProxy4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-EventProxy4Xi" usage = "reasons EventProxy4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        method reason: reasons EventProxy4Xi class objects
        '''
               
        
        class2print = 'EventProxy4Xi'
        method2print = 'reason'

        message2print = "{started" + "; reason-of-EventProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; EventProxy4Xi-reasoning-by-reason-of-EventProxy4Xi: " + str(EventProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-EventProxy4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
                        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        
        message2print = "{reasoned" + "; EventProxy4Xi-reasoned-by-reason-of-EventProxy4Xi: " + str(EventProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-EventProxy4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                           
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-EventProxy4Xi" usage = "aces EventProxy4Xi class objects ">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        method ace: aces EventProxy4Xi class objects 
        '''
               

        class2print = 'EventProxy4Xi'
        method2print = 'ace'
        
        message2print = "{started" + "; ace-of-EventProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; EventProxy4Xi-acing-by-ace-of-EventProxy4Xi: " + str(EventProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                      
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-EventProxy4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
                

        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; EventProxy4Xi-aced-by-ace-of-EventProxy4Xi: " + str(EventProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-EventProxy4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                             
 
                                
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
    #</methodize4xi>
               
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_none4xi.txt
#   sense-test-none4xi.xml
#   reason-test-none4xi.xml
#   ace-test-none4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
 
#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of eventproxy4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>


